@@ -1,5 +1,6 @@
 package Config::Divide::Test;
 use Test::Base -Base;
+use Test::Exception;
 use Data::Dumper;
 use YAML::Syck;
 
@@ -7,21 +8,18 @@ our @EXPORT = qw/
     load
     p
     testdata
+    throws_ok
 /;
 
 sub load () {
-    my $data = shift;
-
-    Config::Divide->load_config(
-        %$data
-    );
+    Config::Divide->load_config( @_ );
 }
 
 sub p () { warn Dumper shift }
 
 sub testdata () {
     my $type = shift->{data_type};
-    YAML::Syck::LoadFile "./t/config/expected/$type.yaml";
+    YAML::Syck::LoadFile( "./t/config/expected/$type.yaml" );
 }
 
 1;
